@@ -25,7 +25,7 @@ img_dir = args.img_dir
 chunk_index = args.chunk_index
 save_datastore_name = args.save_datastore_name
 save_datastore_path = args.save_datastore_path
-save_datasets = json.load(args.save_datasets_json)
+save_datasets = json.loads(args.save_datasets_json)
 
 # Get the experiment run context
 run = Run.get_context()
